pub struct BotAccessSettings {
pub is_access_restricted: bool,
pub added_users: Option<Vec<User>>,
}Expand description
Represents the access settings of a bot.
Fields
is_access_restricted: boolWhether only selected users can access the bot.
The bot’s owner can always access it.
added_users: Option<Vec<User>>The list of other users who have access to the bot if the access is restricted.
Implementations
Sourceimpl BotAccessSettings
impl BotAccessSettings
Sourcepub fn with_added_users<T>(self, value: T) -> BotAccessSettingswhere
T: IntoIterator<Item = User>,
pub fn with_added_users<T>(self, value: T) -> BotAccessSettingswhere
T: IntoIterator<Item = User>,
Sets a new list of added users
Arguments
value- The list of other users who have access to the bot.
Sourcepub fn with_is_access_restricted(self, value: bool) -> BotAccessSettings
pub fn with_is_access_restricted(self, value: bool) -> BotAccessSettings
Sets a new value for the is_access_restricted_flag.
Arguments
value- Whether the only selected users can access the bot.